/************************************************************************/
/*																		*/
/*	ADCI2C.h	--	Declaration for ADCI2C library 	    				*/
/*																		*/
/************************************************************************/
/*	Author:		Cristian Fatu											*/
/*	Copyright 2012, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*	This file declares the ADCI2C library functions and the constants	*/
/*	involved.															*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	01/10/2012(CristianF): created										*/
/*																		*/
/************************************************************************/
#if !defined(ADCI2C_H)
#define ADCI2C_H

/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include <inttypes.h>

/* ------------------------------------------------------------ */
/*					Definitions									*/
/* ------------------------------------------------------------ */
#define ADCI2C_NO_BITS		12
#define ADCI2C_MAX_VAL		((1<<ADCI2C_NO_BITS) - 1)
#define ADCI2C_I2C_ADDR		0x28

#define ADCI2C_MSK_CH0				0x10
#define ADCI2C_MSK_CH1				0x20
#define ADCI2C_MSK_CH2				0x40
#define ADCI2C_MSK_CH3				0x80
#define ADCI2C_MSK_REF_SEL			0x08
#define ADCI2C_MSK_FLTR				0x04
#define ADCI2C_MSK_BIT_TRIAL_DELAY	0x02
#define ADCI2C_MSK_SAMPLE_DELAY		0x01


/* ------------------------------------------------------------ */
/*					Procedure Declarations						*/
/* ------------------------------------------------------------ */

class ADCI2C {
private:
	void WriteByteI2C(uint8_t bVal);
	void GetIntegerValuesNo(uint8_t bCntChannels, uint8_t bConfig, uint16_t &wVal0, uint16_t &wVal1, uint16_t &wVal2, uint16_t &wVal3);
public:
	void RawReadChannels(uint8_t bConfig, uint8_t bCntChannels, uint16_t *rgwValues);
	void GetIntegerValues4Ch(uint16_t &wVal0, uint16_t &wVal1, uint16_t &wVal2, uint16_t &wVal3, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1 | ADCI2C_MSK_CH2 | ADCI2C_MSK_CH3);
	void GetIntegerValues3Ch(uint16_t &wVal0, uint16_t &wVal1, uint16_t &wVal2, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1 | ADCI2C_MSK_CH2);
	void GetIntegerValues2Ch(uint16_t &wVal0, uint16_t &wVal1, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1);
	void GetIntegerValue1Ch(uint16_t &wVal0, uint8_t bConfig = ADCI2C_MSK_CH0);
	void GetPhysicalValues4Ch(float &fVal0, float &fVal1, float &fVal2, float &fVal3, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1 | ADCI2C_MSK_CH2 | ADCI2C_MSK_CH3, float dReference = 3.3);
	void GetPhysicalValues3Ch(float &fVal0, float &fVal1, float &fVal2, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1 | ADCI2C_MSK_CH2, float dReference = 3.3);
	void GetPhysicalValues2Ch(float &fVal0, float &fVal1, uint8_t bConfig = ADCI2C_MSK_CH0 | ADCI2C_MSK_CH1, float dReference = 3.3);
	void GetPhysicalValue1Ch(float &fVal0, uint8_t bConfig = ADCI2C_MSK_CH0, float dReference = 3.3);
	void begin();
};



#endif